Project

General

Profile

Feature #2794 » patch-2794.txt

Sonja Schubert, 2009-03-09 14:57

 
### Eclipse Workspace Patch 1.0
#P igeworkspace42
Index: t3lib/stddb/tables.php
===================================================================
--- t3lib/stddb/tables.php (revision 270)
+++ t3lib/stddb/tables.php (working copy)
@@ -348,8 +348,8 @@
);
/**
- * Table "sys_filemounts":
- * Defines filepaths on the server which can be mounted for users so they can upload and manage files online by eg. the Filelist module
+ * Table "sys_workspace":
+ * Defines workspace configurations for workspaces used by users to manage/create versions of website
* This is only the 'header' part (ctrl). The full configuration is found in t3lib/stddb/tbl_be.php
*/
$TCA['sys_workspace'] = array(
@@ -368,6 +368,26 @@
);
/**
+ * Table "sys_workspace_stage":
+ * Defines single custom stages which are related to sys_workspace table to create complex working processes
+ * This is only the 'header' part (ctrl). The full configuration is found in t3lib/stddb/tbl_be.php
+ */
+$TCA['sys_workspace_stage'] = array(
+ 'ctrl' => array(
+ 'label' => 'title',
+ 'tstamp' => 'tstamp',
+ 'sortby' => 'sorting',
+ 'title' => 'LLL:EXT:lang/locallang_tca.php:sys_workspace_stage',
+ 'adminOnly' => 1,
+ 'rootLevel' => 1,
+ 'delete' => 'deleted',
+ 'iconfile' => 'sys_workspace.png',
+ 'dynamicConfigFile' => 'T3LIB:tbl_be.php',
+ 'versioningWS_alwaysAllowLiveEdit' => true,
+ )
+);
+
+/**
* Table "sys_languages":
* Defines possible languages used for translation of records in the system
* This is only the 'header' part (ctrl). The full configuration is found in t3lib/stddb/tbl_be.php
@@ -437,6 +457,7 @@
t3lib_extMgm::addLLrefForTCAdescr('sys_filemounts','EXT:lang/locallang_csh_sysfilem.xml');
t3lib_extMgm::addLLrefForTCAdescr('sys_language','EXT:lang/locallang_csh_syslang.xml');
t3lib_extMgm::addLLrefForTCAdescr('sys_workspace','EXT:lang/locallang_csh_sysws.xml');
+t3lib_extMgm::addLLrefForTCAdescr('sys_workspace_stage','EXT:lang/locallang_csh_sysws_stage.xml');
t3lib_extMgm::addLLrefForTCAdescr('xMOD_csh_corebe','EXT:lang/locallang_csh_corebe.xml'); // General Core
t3lib_extMgm::addLLrefForTCAdescr('_MOD_tools_em','EXT:lang/locallang_csh_em.xml'); // Extension manager
t3lib_extMgm::addLLrefForTCAdescr('_MOD_web_info','EXT:lang/locallang_csh_web_info.xml'); // Web > Info
Index: t3lib/stddb/tables.sql
===================================================================
--- t3lib/stddb/tables.sql (revision 270)
+++ t3lib/stddb/tables.sql (working copy)
@@ -252,12 +252,33 @@
swap_modes tinyint(3) DEFAULT '0' NOT NULL,
publish_access tinyint(3) DEFAULT '0' NOT NULL,
stagechg_notification tinyint(3) DEFAULT '0' NOT NULL,
+ use_custom_staging tinyint(3) DEFAULT '0' NOT NULL,
+ custom_stages int(11) DEFAULT '0' NOT NULL,
PRIMARY KEY (uid),
KEY parent (pid)
);
#
+# Table structure for table 'sys_workspace_stage'
+#
+CREATE TABLE sys_workspace_stage (
+ uid int(11) NOT NULL auto_increment,
+ pid int(11) DEFAULT '0' NOT NULL,
+ tstamp int(11) DEFAULT '0' NOT NULL,
+ deleted tinyint(1) DEFAULT '0' NOT NULL,
+ sorting int(11) unsigned DEFAULT '0' NOT NULL,
+ title varchar(30) DEFAULT '' NOT NULL,
+ responsible_persons varchar(255) DEFAULT '' NOT NULL,
+ default_mailcomment text,
+ parentid int(11) DEFAULT '0' NOT NULL,
+ parenttable tinytext NOT NULL,
+
+ PRIMARY KEY (uid),
+ KEY parent (pid)
+);
+
+#
# Table structure for table 'sys_history'
#
CREATE TABLE sys_history (
(2-2/2)
Index: t3lib/stddb/tbl_be.php
===================================================================
--- t3lib/stddb/tbl_be.php (revision 270)
+++ t3lib/stddb/tbl_be.php (working copy)
@@ -25,7 +25,7 @@
* This copyright notice MUST APPEAR in all copies of the script!
***************************************************************/
/**
* Contains the dynamic configuation of the fields in the core tables of TYPO3: be_users, be_groups, sys_filemounts and sys_workspace
*
* $Id: tbl_be.php 3656 2008-05-16 09:23:30Z dmitry $
* Revised for TYPO3 3.6 July/2003 by Kasper Skaarhoj
@@ -891,12 +891,32 @@
),
)
),
+ 'use_custom_staging' => array(
+ 'label' => 'LLL:EXT:lang/locallang_tca.xml:sys_workspace.use_custom_staging',
+ 'config' => array(
+ 'type' => 'check',
+ 'default' => '0'
+ )
+ ),
+ 'custom_stages' => Array (
+ 'exclude' => 1,
+ 'label' => 'LLL:EXT:lang/locallang_tca.xml:sys_workspace.custom_stages',
+ 'config' => Array (
+ 'type' => 'inline',
+ 'foreign_table' => 'sys_workspace_stage',
+ 'appearance' => 'useSortable,expandSingle',
+ 'foreign_field' => 'parentid',
+ 'foreign_table_field' => 'parenttable'
+ ),
+ 'default' => 0
+ ),
),
'types' => array(
'0' => array('showitem' => 'title,description,
--div--;LLL:EXT:lang/locallang_tca.xml:sys_filemounts.tabs.users,adminusers,members,reviewers,stagechg_notification,
--div--;LLL:EXT:lang/locallang_tca.xml:sys_filemounts.tabs.mountpoints,db_mountpoints,file_mountpoints,
--div--;LLL:EXT:lang/locallang_tca.xml:sys_filemounts.tabs.publishing,publish_time,unpublish_time,
+ --div--;LLL:EXT:lang/locallang_tca.xml:sys_filemounts.tabs.staging,use_custom_staging,custom_stages,
--div--;LLL:EXT:lang/locallang_tca.xml:sys_filemounts.tabs.other,freeze,live_edit,review_stage_edit,disable_autocreate,swap_modes,vtypes,publish_access'
)
)
@@ -905,6 +925,65 @@
/**
+ * Workspace stages - Defines the single workspace stages which are related to a workspace.
+ */
+$TCA['sys_workspace_stage'] = array(
+ 'ctrl' => $TCA['sys_workspace_stage']['ctrl'],
+ 'columns' => array(
+ 'title' => array(
+ 'label' => 'LLL:EXT:lang/locallang_general.xml:LGL.title',
+ 'config' => array(
+ 'type' => 'input',
+ 'size' => '20',
+ 'max' => '30',
+ 'eval' => 'required,trim,unique'
+ )
+ ),
+ 'responsible_persons' => array(
+ 'label' => 'LLL:EXT:lang/locallang_tca.xml:sys_workspace_stage.responsible_persons',
+ 'config' => array(
+ 'type' => 'group',
+ 'internal_type' => 'db',
+ 'allowed' => 'be_users',
+ 'size' => '3',
+ 'maxitems' => '20',
+ 'autoSizeMax' => 20,
+ 'show_thumbs' => '1'
+ )
+ ),
+ 'default_mailcomment' => array(
+ 'label' => 'LLL:EXT:lang/locallang_tca.xml:sys_workspace_stage.default_mailcomment',
+ 'config' => array(
+ 'type' => 'text',
+ 'rows' => 5,
+ 'cols' => 30
+ )
+ ),
+ 'parentid' => Array (
+ 'exclude' => 0,
+ 'label' => 'LLL:EXT:lang/locallang_tca.xml:sys_workspace_stage.parentid',
+ 'config' => Array (
+ 'type' => 'passthrough',
+ )
+ ),
+ 'parenttable' => Array (
+ 'exclude' => 0,
+ 'label' => 'LLL:EXT:lang/locallang_tca.xml:sys_workspace_stage.parenttable',
+ 'config' => Array (
+ 'type' => 'passthrough',
+ )
+ ),
+ ),
+ 'types' => array(
+ '0' => array('showitem' => 'title,responsible_persons,default_mailcomment'
+ )
+ )
+);
+
+
+
+
+/**
* System languages - Defines possible languages used for translation of records in the system
*/
$TCA['sys_language'] = array(
@@ -25,7 +25,7 @@
***************************************************************/
/**
- * Contains the dynamic configuation of the fields in the core tables of TYPO3: be_users, be_groups, sys_filemounts and sys_workspace
+ * Contains the dynamic configuation of the fields in the core tables of TYPO3: be_users, be_groups, sys_filemounts sys_workspace and sys_workspace_stage
*
* $Id: tbl_be.php 3656 2008-05-16 09:23:30Z dmitry $